@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /cvsroot/pgpool/pgpool/main.c,v 1.9 2005/11/09 14:12:21 t-ishii Exp $
+ * $Header: /cvsroot/pgpool/pgpool/main.c,v 1.10 2006/01/03 03:33:10 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -781,7 +781,7 @@ static RETSIGTYPE failover_handler(int sig)
 	 * if not in replication mode/master slave mode, we treat this a restart request.
 	 * otherwise we need to check if we have already failovered.
 	 */
-	if (!pool_config.replication_enabled || !pool_config.master_slave_enabled ||
+	if (pool_config.replication_enabled || pool_config.master_slave_enabled ||
 		strcmp(pool_config.current_backend_host_name, pool_config.secondary_backend_host_name) ||
 		pool_config.current_backend_port != pool_config.secondary_backend_port)
 	{
@@ -807,6 +807,27 @@ static RETSIGTYPE failover_handler(int sig)
 				pool_config.server_status[0] = 2;		/* mark this down */
 			}
 		}
+
+		else if (pool_config.master_slave_enabled)
+		{
+			degenerated = 1;
+
+			if (sig == SIGUSR2)
+			{
+				pool_log("starting degeneration. shutdown slave host %s(%d)",
+						 pool_config.secondary_backend_host_name,
+						 pool_config.secondary_backend_port);
+				pool_config.server_status[1] = 2;		/* mark this down */
+			}
+			else
+			{
+				pool_log("starting degeneration. shutdown master host %s(%d)",
+						 pool_config.backend_host_name,
+						 pool_config.backend_port);
+				pool_config.server_status[0] = 2;		/* mark this down */
+			}
+		}
+
 		else if (!degenerated && pool_config.secondary_backend_port != 0)
 		{
 			pool_log("starting failover from %s(%d) to %s(%d)",
@@ -849,6 +870,19 @@ static RETSIGTYPE failover_handler(int sig)
 				pool_config.current_backend_port = pool_config.secondary_backend_port;
 			}
 		}
+
+		else if (pool_config.master_slave_enabled)
+		{
+			/* disable master/slave mode */
+			pool_config.master_slave_enabled = 0;
+
+			if (sig == SIGUSR1)
+			{
+				pool_config.current_backend_host_name = pool_config.secondary_backend_host_name;
+				pool_config.current_backend_port = pool_config.secondary_backend_port;
+			}
+		}
+
 		else if (!degenerated && pool_config.secondary_backend_port != 0)
 		{
 			/* fail over to secondary */
