@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
-* $Header: /cvsroot/pgpool/pgpool/pool_stream.c,v 1.4 2005/07/30 12:30:20 t-ishii Exp $
+* $Header: /cvsroot/pgpool/pgpool/pool_stream.c,v 1.5 2006/01/03 03:33:10 t-ishii Exp $
 *
 * pgpool: a language independent connection pool server for PostgreSQL 
 * written by Tatsuo Ishii
@@ -585,6 +585,14 @@ char *pool_read_string(POOL_CONNECTION *cp, int *len, int line)
 			    return NULL;
 			}
 		}
+		else if (readlen == 0)	/* EOF detected */
+		{
+			/*
+			 * just returns an error, not trigger failover or degeneration
+			 */
+			pool_error("pool_read_string: read () EOF detected");
+			return NULL;
+		}
 
 		/* check overrun */
 		if (line)
